Telescope Workflows
=======================
A telescope a type of workflow used to ingest data from different data sources, and to run workflows that process and
output data to other places. Workflows are built on top of Apache Airflow's DAGs.

.. toctree::
    :maxdepth: 1

    crossref_events
    crossref_fundref
    crossref_metadata
    geonames
    grid
    mag
    orcid
    scopus
    unpaywall
    web_of_science
